爱在日落黄昏时 (豆瓣)
Description: 爱在日落黄昏时电影简介和剧情介绍,爱在日落黄昏时影评、图片、预告片、影讯、论坛、在线购票
Keywords: 爱在日落黄昏时,Before Sunset,爱在日落黄昏时影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.118豆瓣电影Top250

# 爱在日落黄昏时 Before Sunset (2004)

导演: 理查德·林克莱特
编剧: 理查德·林克莱特 / 朱莉·德尔佩 / 伊桑·霍克 / 金·克里桑
主演: 伊桑·霍克 / 朱莉·德尔佩 / 弗农·多布切夫 / 路易丝·勒莫瓦纳·托雷斯 / 罗多尔·保利 / 玛丽安·普莱施泰格 / 迪亚博洛 / 丹尼·弗拉 / 艾伯特·德尔佩 / 玛丽·佩里
类型: 剧情 / 爱情
制片国家/地区: 美国 / 法国
语言: 英语 / 法语
上映日期: 2004-02-10(柏林电影节) / 2004-07-30(美国)
片长: 80 分钟
又名: 日落巴黎(港) / 爱在日落巴黎时(台) / 日落之前 / 情留相逢时 / 爱在日落余晖时 / 爱在日落黄昏前
IMDb: tt0381681
豆瓣评分
引用
8.9
523688人评价
5星
55.8%
4星
34.3%
3星
8.8%
2星
0.8%
1星
0.3%
好于 98% 爱情片
好于 98% 剧情片
想看 看过
评价:
推荐

## 爱在日落黄昏时的剧情简介 · · · · · ·

九年前，杰西（伊桑·霍克 Ethan Hawke 饰）与席琳（朱莉·德尔佩 Julie Delpy 饰）在火车上不期而遇，怦然心动。在维也纳渡过疯狂而又浪漫的一夜后，他们在日出前分手，并相约在维也纳重逢。
九年之后，杰西已成为畅销书作家，而席琳则是法国环保组织成员。杰西在新书里娓娓道来的，正是九年前的浪漫夜晚。在巴黎促销新书时，杰西与席琳在书店相遇，然而他们只有一下午的时光相处，日落之前，杰西要乘飞机赶回美国。两人在午后的巴黎街头散步，在美丽的护城河上泛舟，无所不谈，兴致勃勃。可是就像命运的捉弄，快乐的时光像烟花一样醉人却短暂。
杰西对席琳一送再送，难以忘情；席琳用吉他和歌声，怀念着内心深处的爱恋。太阳就快落下去了，杰西就要误了飞机，又或许他更不想错过的，是命里注定的缘分。 ©豆瓣

## 爱在日落黄昏时的演职员 · · · · · · ( 全部 18 )

- 理查德·林克莱特 导演
- 伊桑·霍克 饰 Jesse
- 朱莉·德尔佩 饰 Céline
- 弗农·多布切夫 饰 Bookstore Manager
- 路易丝·勒莫瓦纳·托雷斯 饰 Journalist #1
- 罗多尔·保利 饰 Journalist #2

## 爱在日落黄昏时的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片750 · 添加 )

## 爱在日落黄昏时的获奖情况 · · · · · · ( 全部 )

- 第77届奥斯卡金像奖
- 最佳改编剧本(提名)
- 伊桑·霍克 / 理查德·林克莱特 / 朱莉·德尔佩 / 金·克里桑

- 第54届柏林国际电影节
- 金熊奖 最佳影片(提名)
- 理查德·林克莱特

## 喜欢这部电影的人也喜欢 · · · · · ·

  爱在黎明破晓前

  罗马假日

  恋恋笔记本

  重庆森林

  花样年华

  甜蜜蜜

  傲慢与偏见

  爱乐之城

  真爱至上

  天使爱美丽

我要写短评

## 爱在日落黄昏时的短评 · · · · · · ( 全部 127827 条 )

热门 / 最新 / 好友

### 463 有用 A-sun* 看过 2010-04-21 21:54:40

哪浪漫了。哪浪漫了。我老了。我老了。我老了。

### 3612 有用 荒也 看过 2012-09-05 01:34:25

最喜欢一起上楼梯那段，也是两小时话痨电影里唯一没有对话的一段，和九年前两人在视听室里一样，安静，尴尬，暧昧得浓厚。

### 3520 有用 南笙 看过 2012-01-06 23:29:25

最后的结尾，杰西坐在沙发上似笑非笑的看着塞林，他一定在想，这个女人太他妈可爱，可爱的想立即上了她，再娶她。

### 4296 有用 桃桃林林 看过 2010-06-06 20:03:28

他为她写了本书，她为他写了首歌。其实，他们都记得，每个细节。这部就是来还愿的，又是一个开放式的结局。我想这次他们应该不会错过彼此了吧。

### 4951 有用 大头绿豆 看过 2006-09-25 22:59:01

“从某种意义上来说，我所有的浪漫 都在一夜之间消耗光了...”

> 更多短评 127827条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 爱在日落黄昏时的影评 · · · · · · ( 全部 2494 条 )

热门 / 最新 / 好友
筱晗 2008-06-20 01:58:19

## 原来你也在这里

其实，爱过了你，我还能爱谁？ 我误了飞机，也不想再误了你。 他为了宣传他的新书来到了巴黎，她在书店的外面看他，一脸讳莫如深。 他看见了她，一如九年前，他在火车上第一次看见她。 他们走在巴黎的小道上，一如九年前穿过维也纳的小巷。他瘦了，也老了，却更添成熟；她也... (展开)
2298 110 312回应 收起
家家安安 2009-03-13 13:26:21

## 写给80后的初恋

你有没有过这样的经历。 你一路上走走停停删删减减，但在某个日落黄昏整理行囊时发现，那个你本以为早被丢下的旧物赫然躺在角落里，磨损的边角满是低眉顺眼的亲切。 你用十年的时间邂逅不同的爱人，你学会了适时的微笑和撒娇。 但在某个措手不急的瞬间，你偶遇当初的他，青涩... (展开)
681 45 172回应 收起
娘卷卷🌻 2008-08-06 12:27:33

## 一刻，还是一生？

这是观后感啊不是影评： 题记：生命从来就没有圆满，但是必须有美好和幸福，至少这部电影，是的，在我眼中，已经是完美的一场梦了。一切都在意料之中，每一个细节又都在意料之外。是的，我们都有永远都逃不开的痛苦，逃不开现实和爱的矛盾。但是，激情和绝望也会一起壮大。如... (展开)
597 17 117回应 收起
贾三变 2008-04-10 10:55:30

## 九年后

九年后，他们相遇了，一个额上多了几道抬头纹，一个有些消瘦但充满成熟女人的风韵。 我仍然是把自己锁在会议室里，独自盯着大屏幕的瑟琳和杰西，咂摸着茶水津津有味地听他俩唠唠叨叨的没完…… 和前一个通宵熬着看他俩的维也纳浪漫邂逅的感觉不同， 倒不是因为... (展开)
372 19 91回应 收起
鲲儿 2007-06-17 20:15:58

## 爱在日出日落时

序 有些事情感悟一下就是美好，不一定非要给自己一个见证。当初的真挚感情若留在记忆里可能单纯而美好，倘若付诸笔端，便是多少年后的唏嘘不已。但有时自己就是倔强到如此地步，以为不得不写点什么，而正襟危坐于桌前时，才发现心中所想一目... (展开)
270 16 73回应 收起
alyssa 2007-12-10 14:37:07

## 爱不是朝夕，而是惊鸿一瞥

《befor sunrise》 《 before sunset 》两部片子我是同时看的，此同时不是看了前者接着看后者，而是两者交叉，因为土豆在线缓冲慢，而我又等不及，跳跃在时空中，享受着落差的美。 当青葱岁月碰上内心的冒险，必定上演奇幻与瑰丽的梦，昙花一现，霎时永恒。夜里的彼此如上帝突... (展开)
204 8 47回应 收起
Bauer 2006-10-02 16:23:14

## 生命里的那段爱情

这两天把Before Sunrise和Before Sunset一并看了，Before Sunset更是连看了两遍到深夜。自己码字实在很慢，但是担心不写点什么，心里那些感慨就像人生里边的许许多多片断，散得不留痕迹，无从回忆，所以还是写点儿。 Before Sunrise是写两个陌生的年轻人，男的Jesse来自美国，... (展开)
132 3 34回应 收起
木西 2005-05-10 12:48:53

## 九年之爱

我想把这部电影详细的介绍一下 美国导演理查德林克莱特带给我们的电影《爱在黎明破晓时（Before Sunrise）》及其续集《爱在日落余辉时（Before Sunset）》所讲述的故事。前者拍于1995年，后者拍于2004年。两部电影亦时隔九年。 美国男青年杰西在从布达佩斯向西开行的列车上... (展开)
83 5 28回应 收起
闫妮 2017-05-27 15:07:51

## 弹吉他对唱是我最美的梦

这篇影评可能有剧透

从《Before Sunrise》到《Before Sunset》，戏里戏外都是9年。如果说前篇讲的是一生仅有的最浪漫的一夜，Sunse讲的就是最遗憾的错过和最难得的重逢。上一部结尾，他们相约6个月后见。然而错过了。当9年之后，Celine淡淡地微笑着出现在书店的角落时，还是令人惊喜，Jesse为他们... (展开)
77 8 4回应 收起
ellajma 2005-06-06 05:06:20

## nine years later

I watched “Before Sunrise” first, then “Before Sunset”. I loved “before sunset”, the sequel made nine years later, better. It’s probably because of my age, I found more relevance to the second movie. “Before sunrise” is story of 20 somethings. You ... (展开)
65 4 15回应 收起

> 更多影评 2494篇

添加新讨论

## 讨论区 · · · · · ·

看了一半，最终没能看下去 | 来自SilverWing | 129 回应 | 2022-11-17 15:59:56
想知道看第二部时，大家的年纪 | 来自. | 24 回应 | 2022-11-17 14:33:22
会不会几年后再拍一部？ | 来自Moss大妖 | 98 回应 | 2022-11-17 07:06:36
叨逼叨…哪好？ | 来自豆友216562460 | 1 回应 | 2022-11-12 14:20:03
Before.Sunset.2004.BDRemux.1080p_by_vedigo | 来自屋DA |  | 2022-11-10 17:57:04

> 去这部影片的讨论区（全部270条）

## 关于《爱在日落黄昏时》的问题 · · · · · · ( 全部20个 )

- 9年前 杰西到底去维也纳赴约了吗？ 7人回答
- 大家有没有发现女主角大门上贴了个恭喜发财的小人贴纸？ 9人回答

> 全部20个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 桃桃推荐｜值得一看（209部） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- 咳嗽的夜鸟
  1分钟前 看过
- importantwin
  3分钟前 想看
- momo
  3分钟前 看过

746448人看过 / 401585人想看

订阅爱在日落黄昏时的评论:
feed: rss 2.0